from django.urls import include, path
from django.contrib.auth import views as auth_views

from . import views

urlpatterns = [

    # authentication
    path('accounts/', include('django.contrib.auth.urls')),

    # specialization of the above, with more control
    path('login/', auth_views.LoginView.as_view(template_name='registration/login.html')),

    # --- GUI ---
    path('', views.IndexView.as_view(), name='homepage'),

    path('task_details/<int:id>/<page>', views.TaskDetails, name='task-details'),
    path('task_details/', views.TaskDetails, name='task-details'),

    path('show-inputs/<int:id>/', views.ShowInputs, name='show-inputs'),
    path('show-outputs/<int:id>/', views.ShowOutputs, name='show-outputs'),
    path('show-metrics/<int:id>/', views.ShowMetrics, name='show-metrics'),
    path('dashboard/<selection>', views.ShowDashboard, name='dashboard'),

    path('workflow_details/<id>/', views.WorkflowDetails, name='workflow-details'),
    path('query/', views.QueryView.as_view(), name='query'),
    # path('dashboard/', views.DashboardView.as_view(), name='dashboard'),
    path('config/', views.ShowConfig, name='config'),
    path('diagram/', views.DiagramView.as_view(), name='diagram'),

    # --- REST API ---
    path('tasks/', views.TaskListViewAPI.as_view(), name='tasks-api'),
    path('tasks/<int:pk>/', views.TaskDetailsViewAPI.as_view(), name='task-detail-view-api'),
    path('tasks-fast/', views.TaskListViewAPIFast.as_view(), name='tasks-api-fast'),
    path('tasks-fast/<int:pk>/', views.TaskDetailsViewAPIFast.as_view(), name='task-detail-view-api-fast'),

    path('workflows/', views.WorkflowListViewAPI.as_view(), name='workflows-api'),
    path('workflows/<int:pk>/', views.WorkflowDetailsViewAPI.as_view(), name='workflow-detail-view-api'),

    path('logentries/', views.LogEntryListViewAPI.as_view()),
    path('logentries/<int:pk>/', views.LogEntryDetailsViewAPI.as_view(), name='logentry-detail-view-api'),

    path('configuration/', views.ConfigurationListViewAPI.as_view()),
    path('configuration/<int:pk>/', views.ConfigurationDetailsViewAPI.as_view(), name='configuration-detail-view-api'),

    path('jobs/', views.JobListViewAPI.as_view()),
    path('jobs/<int:pk>/', views.JobDetailsViewAPI.as_view(), name='job-detail-view-api'),

    # --- custom requests ---
    # /atdb/get_size?status__in=defined,staged
    path('tasks/get_size/', views.GetSizeView.as_view(), name='get-size-view'),

    # --- controller resources ---
    path('tasks/<int:pk>/setstatus/<new_status>/<page>', views.TaskSetStatus, name='task-setstatus-view'),
    path('tasks/<int:pk>/setstatus/<new_status>', views.TaskSetStatus, name='task-details-setstatus'),

    path('tasks/<int:pk>/change_priority/<priority_change>/<page>', views.ChangePriority, name='task-change-priority'),
    path('tasks/<int:pk>/change_priority/<priority_change>', views.ChangePriority, name='task-change-priority'),
    path('tasks/sort-tasks/<sort>', views.SortTasks, name='sort-tasks'),


    path('tasks/set_filter/<filter>', views.TaskSetFilter, name='task-set-filter'),
    path('tasks/set_active_filter', views.TaskSetActiveFilter, name='task-set-active-filter'),
    path('tasks/task-set-onhold-filter/<onhold>', views.TaskSetOnHoldFilter, name='task-set-onhold-filter'),
    path('tasks/<int:pk>/set_status/<new_status>/<page>', views.TaskSetStatusTables2, name = 'task-setstatus'),
    path('tasks/set_status_multi/<new_status>', views.TaskMultiStatus, name='task-multi-setstatus'),
    path('tasks/set_multi_hold/<onhold>', views.TaskMultiHold, name='task-multi-hold'),

    path('tasks/<int:pk>/hold/<hold_it>/<page>', views.Hold, name='task-hold-resume'),
    path('tasks/<int:pk>/hold/<hold_it>', views.Hold, name='task-hold-resume'),
]